@@ -21,17 +21,20 @@ import java.io.Serializable;
 import java.lang.reflect.Array;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.time.Duration;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Objects;
 import java.util.TreeSet;
 import java.util.function.Supplier;
 
 import org.apache.commons.lang3.exception.CloneFailedException;
 import org.apache.commons.lang3.mutable.MutableInt;
 import org.apache.commons.lang3.text.StrBuilder;
+import org.apache.commons.lang3.time.DurationUtils;
 
 /**
  * <p>Operations on {@code Object}.</p>
@@ -75,7 +78,6 @@ public class ObjectUtils {
          * Restricted constructor - singleton.
          */
         Null() {
-            super();
         }
 
         /**
@@ -107,32 +109,6 @@ public class ObjectUtils {
      */
     public static final Null NULL = new Null();
 
-    /**
-     * Checks if all values in the given array are {@code null}.
-     *
-     * <p>
-     * If all the values are {@code null} or the array is {@code null}
-     * or empty, then {@code true} is returned, otherwise {@code false} is returned.
-     * </p>
-     *
-     * <pre>
-     * ObjectUtils.allNull(*)                = false
-     * ObjectUtils.allNull(*, null)          = false
-     * ObjectUtils.allNull(null, *)          = false
-     * ObjectUtils.allNull(null, null, *, *) = false
-     * ObjectUtils.allNull(null)             = true
-     * ObjectUtils.allNull(null, null)       = true
-     * </pre>
-     *
-     * @param values  the values to test, may be {@code null} or empty
-     * @return {@code true} if all values in the array are {@code null}s,
-     * {@code false} if there is at least one non-null value in the array.
-     * @since 3.11
-     */
-    public static boolean allNull(final Object... values) {
-        return !anyNotNull(values);
-    }
-
     /**
      * Checks if all values in the array are not {@code nulls}.
      *
@@ -173,31 +149,29 @@ public class ObjectUtils {
     }
 
     /**
-     * Checks if any value in the given array is {@code null}.
+     * Checks if all values in the given array are {@code null}.
      *
      * <p>
-     * If any of the values are {@code null} or the array is {@code null},
-     * then {@code true} is returned, otherwise {@code false} is returned.
+     * If all the values are {@code null} or the array is {@code null}
+     * or empty, then {@code true} is returned, otherwise {@code false} is returned.
      * </p>
      *
      * <pre>
-     * ObjectUtils.anyNull(*)             = false
-     * ObjectUtils.anyNull(*, *)          = false
-     * ObjectUtils.anyNull(null)          = true
-     * ObjectUtils.anyNull(null, null)    = true
-     * ObjectUtils.anyNull(null, *)       = true
-     * ObjectUtils.anyNull(*, null)       = true
-     * ObjectUtils.anyNull(*, *, null, *) = true
+     * ObjectUtils.allNull(*)                = false
+     * ObjectUtils.allNull(*, null)          = false
+     * ObjectUtils.allNull(null, *)          = false
+     * ObjectUtils.allNull(null, null, *, *) = false
+     * ObjectUtils.allNull(null)             = true
+     * ObjectUtils.allNull(null, null)       = true
      * </pre>
      *
      * @param values  the values to test, may be {@code null} or empty
-     * @return {@code true} if there is at least one {@code null} value in the array,
-     * {@code false} if all the values are non-null.
-     * If the array is {@code null} or empty, {@code true} is also returned.
+     * @return {@code true} if all values in the array are {@code null}s,
+     * {@code false} if there is at least one non-null value in the array.
      * @since 3.11
      */
-    public static boolean anyNull(final Object... values) {
-        return !allNotNull(values);
+    public static boolean allNull(final Object... values) {
+        return !anyNotNull(values);
     }
 
     /**
@@ -227,6 +201,34 @@ public class ObjectUtils {
         return firstNonNull(values) != null;
     }
 
+    /**
+     * Checks if any value in the given array is {@code null}.
+     *
+     * <p>
+     * If any of the values are {@code null} or the array is {@code null},
+     * then {@code true} is returned, otherwise {@code false} is returned.
+     * </p>
+     *
+     * <pre>
+     * ObjectUtils.anyNull(*)             = false
+     * ObjectUtils.anyNull(*, *)          = false
+     * ObjectUtils.anyNull(null)          = true
+     * ObjectUtils.anyNull(null, null)    = true
+     * ObjectUtils.anyNull(null, *)       = true
+     * ObjectUtils.anyNull(*, null)       = true
+     * ObjectUtils.anyNull(*, *, null, *) = true
+     * </pre>
+     *
+     * @param values  the values to test, may be {@code null} or empty
+     * @return {@code true} if there is at least one {@code null} value in the array,
+     * {@code false} if all the values are non-null.
+     * If the array is {@code null} or empty, {@code true} is also returned.
+     * @since 3.11
+     */
+    public static boolean anyNull(final Object... values) {
+        return !allNotNull(values);
+    }
+
     // cloning
     //-----------------------------------------------------------------------
     /**
@@ -804,11 +806,11 @@ public class ObjectUtils {
      *
      * @param appendable  the appendable to append to
      * @param object  the object to create a toString for
-     * @throws IOException if an I/O error occurs
+     * @throws IOException if an I/O error occurs.
      * @since 3.2
      */
     public static void identityToString(final Appendable appendable, final Object object) throws IOException {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         appendable.append(object.getClass().getName())
               .append(AT_SIGN)
               .append(Integer.toHexString(System.identityHashCode(object)));
@@ -866,7 +868,7 @@ public class ObjectUtils {
      */
     @Deprecated
     public static void identityToString(final StrBuilder builder, final Object object) {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         final String name = object.getClass().getName();
         final String hexString = Integer.toHexString(System.identityHashCode(object));
         builder.ensureCapacity(builder.length() +  name.length() + 1 + hexString.length());
@@ -891,7 +893,7 @@ public class ObjectUtils {
      * @since 2.4
      */
     public static void identityToString(final StringBuffer buffer, final Object object) {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         final String name = object.getClass().getName();
         final String hexString = Integer.toHexString(System.identityHashCode(object));
         buffer.ensureCapacity(buffer.length() + name.length() + 1 + hexString.length());
@@ -916,7 +918,7 @@ public class ObjectUtils {
      * @since 3.2
      */
     public static void identityToString(final StringBuilder builder, final Object object) {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         final String name = object.getClass().getName();
         final String hexString = Integer.toHexString(System.identityHashCode(object));
         builder.ensureCapacity(builder.length() +  name.length() + 1 + hexString.length());
@@ -1063,7 +1065,7 @@ public class ObjectUtils {
     public static <T> T median(final Comparator<T> comparator, final T... items) {
         Validate.notEmpty(items, "null/empty items");
         Validate.noNullElements(items);
-        Validate.notNull(comparator, "null comparator");
+        Validate.notNull(comparator, "comparator");
         final TreeSet<T> sort = new TreeSet<>(comparator);
         Collections.addAll(sort, items);
         @SuppressWarnings("unchecked") //we know all items added were T instances
@@ -1183,6 +1185,64 @@ public class ObjectUtils {
         return !equals(object1, object2);
     }
 
+    /**
+     * Checks that the specified object reference is not {@code null} or empty per {@link #isEmpty(Object)}. Use this
+     * method for validation, for example:
+     *
+     * <blockquote>
+     *
+     * <pre>
+     * public Foo(Bar bar) {
+     *     this.bar = Objects.requireNonEmpty(bar);
+     * }
+     * </pre>
+     *
+     * </blockquote>
+     *
+     * @param <T> the type of the reference.
+     * @param obj the object reference to check for nullity.
+     * @return {@code obj} if not {@code null}.
+     * @throws NullPointerException     if {@code obj} is {@code null}.
+     * @throws IllegalArgumentException if {@code obj} is empty per {@link #isEmpty(Object)}.
+     * @see #isEmpty(Object)
+     * @since 3.12.0
+     */
+    public static <T> T  requireNonEmpty(final T obj) {
+        return requireNonEmpty(obj, "object");
+    }
+
+    /**
+     * Checks that the specified object reference is not {@code null} or empty per {@link #isEmpty(Object)}. Use this
+     * method for validation, for example:
+     *
+     * <blockquote>
+     *
+     * <pre>
+     * public Foo(Bar bar) {
+     *     this.bar = Objects.requireNonEmpty(bar, "bar");
+     * }
+     * </pre>
+     *
+     * </blockquote>
+     *
+     * @param <T> the type of the reference.
+     * @param obj the object reference to check for nullity.
+     * @param message the exception message.
+     * @return {@code obj} if not {@code null}.
+     * @throws NullPointerException     if {@code obj} is {@code null}.
+     * @throws IllegalArgumentException if {@code obj} is empty per {@link #isEmpty(Object)}.
+     * @see #isEmpty(Object)
+     * @since 3.12.0
+     */
+    public static <T> T requireNonEmpty(final T obj, final String message) {
+        // check for null first to give the most precise exception.
+        Objects.requireNonNull(obj, message);
+        if (isEmpty(obj)) {
+            throw new IllegalArgumentException(message);
+        }
+        return obj;
+    }
+
     // ToString
     //-----------------------------------------------------------------------
     /**
@@ -1209,7 +1269,6 @@ public class ObjectUtils {
     public static String toString(final Object obj) {
         return obj == null ? StringUtils.EMPTY : obj.toString();
     }
-
     /**
      * <p>Gets the {@code toString} of an {@code Object} returning
      * a specified text if {@code null} input.</p>
@@ -1260,6 +1319,23 @@ public class ObjectUtils {
         return obj == null ? supplier == null ? null : supplier.get() : obj.toString();
     }
 
+    /**
+     * Calls {@link Object#wait(long, int)} for the given Duration.
+     *
+     * @param obj The receiver of the wait call.
+     * @param duration How long to wait.
+     * @throws IllegalArgumentException if the timeout duration is negative.
+     * @throws IllegalMonitorStateException if the current thread is not the owner of the {@code obj}'s monitor.
+     * @throws InterruptedException if any thread interrupted the current thread before or while the current thread was
+     *         waiting for a notification. The <em>interrupted status</em> of the current thread is cleared when this
+     *         exception is thrown.
+     * @see Object#wait(long, int)
+     * @since 3.12.0
+     */
+    public static void wait(final Object obj, final Duration duration) throws InterruptedException {
+        DurationUtils.accept(obj::wait, DurationUtils.zeroIfNull(duration));
+    }
+
     /**
      * <p>{@code ObjectUtils} instances should NOT be constructed in
      * standard programming. Instead, the static methods on the class should
@@ -1269,7 +1345,6 @@ public class ObjectUtils {
      * instance to operate.</p>
      */
     public ObjectUtils() {
-        super();
     }
 
 }
